@@ -16,7 +16,7 @@ def serialize_json(task):
     return json.dumps(task, separators=(",", ":"), ensure_ascii=False)
 
 
-async def aretry(async_func, times, *args, **kwargs):
+async def aretry(async_func, times: int, *args, **kwargs):
     """Retry an asynchronous function for `times` times
 
     Params:
@@ -28,6 +28,10 @@ async def aretry(async_func, times, *args, **kwargs):
 
     assert isinstance(async_func, (types.FunctionType, types.MethodType))
 
+    # If times <= 0, we retry the async_func until it returns
+    if times < 1:
+        times = 1 << 31
+
     for i in range(times):
         try:
             return await async_func(*args, **kwargs)
